@@ -9,15 +9,13 @@
 
 #include <QWidget>
 
-
 class GradeReferenceWidget : public QWidget
 {
 public:
-    explicit GradeReferenceWidget(QWidget *parent = 0);
+    explicit GradeReferenceWidget(QWidget *parent = nullptr);
 
 protected:
-    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
-
+    void paintEvent(QPaintEvent *) override;
 };
 
 #endif
