@@ -18,16 +18,14 @@
 #include <KEduVocExpression>
 
 // Parley
-#include "testentry.h"
 #include "prefs.h"
-
+#include "testentry.h"
 
 class KEduVocDocument;
 
 namespace Practice
 {
-
-    class SessionManagerContinuous : public SessionManagerBase
+class SessionManagerContinuous : public SessionManagerBase
 {
 public:
     /**
@@ -38,26 +36,24 @@ public:
     /**
      * destructor
      */
-    virtual ~SessionManagerContinuous();
+    ~SessionManagerContinuous() override;
 
     /**
      * Prepare for practice using the entries in this document.
      */
-    void setDocument(KEduVocDocument *doc) Q_DECL_OVERRIDE;
+    void setDocument(KEduVocDocument *doc) override;
 
     /**
      * Initialize the lists of entries that will be used in the
      * training from the full set of available entries.
      */
-    void initializeTraining() Q_DECL_OVERRIDE;
-
+    void initializeTraining() override;
 
     // Not reimplemented.  The default version does what is needed.
-    //virtual TestEntry* nextTrainingEntry();
+    // virtual TestEntry* nextTrainingEntry();
 
-
- private:  // data
-    // The default data in the base class is enough for us.
+private: // data
+         // The default data in the base class is enough for us.
 };
 
 }
